embed_many

Function embed_many 

pub fn embed_many(
    model: impl Into<EmbeddingModelRef>,
    values: impl IntoIterator<Item = impl Into<String>>,
) -> EmbedMany
Embeds several values, splitting them into provider calls by the model’s limits and running the calls concurrently when the model allows it.