Module files

Module files 

Provider file storage: upload_file, get_file_metadata, download_file and delete_file.

Design: docs/01-architecture/11-other-modalities.md 7.

Structs

DeleteFile
Builder returned by delete_file; .await runs the call.
DeleteFileResult
Result of a delete.
DownloadFile
Builder returned by download_file; .await runs the call.
DownloadFileResult
Result of a download.
GetFileMetadata
Builder returned by get_file_metadata; .await runs the call.
UploadFile
Builder returned by upload_file; .await runs the upload.
UploadFileResult
Result of an upload.

Enums

UploadData
Data to upload.

Functions

delete_file
Deletes an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
download_file
Downloads an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
get_file_metadata
Fetches the metadata of an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
upload_file
Uploads a file to the provider’s storage. The media type is detected from the data when not set: text data is text/plain, streams are application/octet-stream.

Type Aliases

FileMetadataResult
Metadata of a stored file.