pub fn delete_file(
files: impl Into<FilesRef>,
file: ProviderReference,
) -> DeleteFileExpand description
Deletes an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
pub fn delete_file(
files: impl Into<FilesRef>,
file: ProviderReference,
) -> DeleteFileDeletes an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.