Provider file storage: upload_file, get_file_metadata,
download_file and delete_file.
Design: docs/01-architecture/11-other-modalities.md 7.
Structs
- Delete
File - Builder returned by
delete_file;.awaitruns the call. - Delete
File Result - Result of a delete.
- Download
File - Builder returned by
download_file;.awaitruns the call. - Download
File Result - Result of a download.
- GetFile
Metadata - Builder returned by
get_file_metadata;.awaitruns the call. - Upload
File - Builder returned by
upload_file;.awaitruns the upload. - Upload
File Result - Result of an upload.
Enums
- Upload
Data - Data to upload.
Functions
- delete_
file - Deletes an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
- download_
file - Downloads an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
- get_
file_ metadata - Fetches the metadata of an uploaded file. Fails with an unsupported functionality error when the provider does not implement it.
- upload_
file - Uploads a file to the provider’s storage. The media type is detected
from the data when not set: text data is
text/plain, streams areapplication/octet-stream.
Type Aliases
- File
Metadata Result - Metadata of a stored file.