pub trait PrepareStep: Send + Sync {
// Required method
fn prepare_step<'a>(
&'a self,
ctx: PrepareStepContext<'a>,
) -> BoxFuture<'a, Result<StepOverrides, Error>>;
}Expand description
Computes overrides before each step.
Implemented for every Fn(&PrepareStepContext<'_>) -> StepOverrides
closure; implement the trait directly when the decision is asynchronous.
Required Methods
Sourcefn prepare_step<'a>(
&'a self,
ctx: PrepareStepContext<'a>,
) -> BoxFuture<'a, Result<StepOverrides, Error>>
fn prepare_step<'a>( &'a self, ctx: PrepareStepContext<'a>, ) -> BoxFuture<'a, Result<StepOverrides, Error>>
Returns the overrides for the step described by ctx.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".