pub struct RealtimeHandle { /* private fields */ }Expand description
Sends events into a realtime session and closes it.
Handles are cheap to clone and remain valid until the session ends.
Implementations
Sourceimpl RealtimeHandle
impl RealtimeHandle
Sourcepub async fn send(&self, event: RealtimeClientEvent) -> Result<(), Error>
pub async fn send(&self, event: RealtimeClientEvent) -> Result<(), Error>
Sends a client event.
Errors
Fails when the model cannot serialize the event or the session is closed.
Sourcepub async fn add_tool_output(
&self,
call_id: &str,
output: &JsonValue,
) -> Result<(), Error>
pub async fn add_tool_output( &self, call_id: &str, output: &JsonValue, ) -> Result<(), Error>
Submits the output of a tool call. A follow-up response is requested once every tool call of the response has an output.
Errors
See RealtimeHandle::send.
Sourcepub async fn request_response(&self) -> Result<(), Error>
pub async fn request_response(&self) -> Result<(), Error>