Reranking: rerank orders documents by relevance to a query.
Design: docs/01-architecture/11-other-modalities.md 5.
Lifecycle behavior is derived from the Vercel AI SDK (Apache-2.0, Copyright 2023 Vercel, Inc.), translated to Rust and modified; see NOTICE.
Structs
- Ranked
- One ranked document.
- Rerank
- Builder returned by
rerank;.awaitruns the call. - Rerank
Call EndEvent - Event after a successful reranking operation, including an empty input.
- Rerank
Call Start Event - Event before any provider attempt of a reranking operation.
- Rerank
Result - Result of
rerank.
Enums
- Rerank
Document - A document to rerank: text or a JSON object.
Functions
- rerank
- Reranks
documentsby relevance toquery. Documents must be all text or all objects.